﻿using Microsoft.AspNetCore.Components;
using Syncfusion.Blazor.Gantt;
using System;
using System.Collections.Generic;
using System.Linq;

namespace Blazor.Pages
{
    public partial class GanttChart : ComponentBase
    {
        [Parameter]
        public List<GanttChartElement> GanttChartElements { get; set; }

        [Parameter]
        public IntervalViewModel Interval { get; set; }

        [Parameter]
        public bool ShowCategories { get; set; }

        [Parameter]
        public EventCallback DisableZoomOut { get; set; }


        public SfGantt<GanttChartElement> GanttChartRef { get; set; }
        public bool IsGanttZoomedToFit { get; set; } = true;

        private DateTime startDate = DateTime.Now;
        private DateTime endDate = DateTime.Now;

        protected override void OnInitialized()
        {
            startDate = Interval.StartDate.GetValueOrDefault();
            endDate = Interval.EndDate.GetValueOrDefault().AddDays(1);
        }

        public void Created(object args)
        {
            ZoomToFitIfProjectsAvailable();
            GanttChartRef.CollapseAllAsync();
        }

        private async void ZoomToFitIfProjectsAvailable()
        {
            if (GanttChartElements.Count > 0 && IsGanttZoomedToFit)
            {
                await GanttChartRef.ZoomToFitAsync();
                IsGanttZoomedToFit = true;
            }
            await DisableZoomOut.InvokeAsync(null);
        }

        private GanttChartElement GetSelectedProject(string projectName)
        {
            if (ShowCategories)
            {
                foreach (var category in GanttChartElements)
                {
                    var selectedProject = category.Projects.FirstOrDefault(project => project.CompositeName == projectName);
                    if (selectedProject != null)
                    {
                        return selectedProject;
                    }
                }
            }
            else
            {
                var selectedProject = GanttChartElements.FirstOrDefault(project => project.CompositeName == projectName);
                if (selectedProject != null)
                {
                    return selectedProject;
                }
            }

            return new GanttChartElement();
        }

        public void SetSelectedInterval(DateTime start, DateTime end)
        {
            startDate = start;
            endDate = end;
            IsGanttZoomedToFit = false;

            //GanttChartRef.Refresh();
        }

    }
}
