﻿using Microsoft.AspNetCore.Components;
using Syncfusion.Blazor.Navigations;
using System;
using System.Collections.Generic;
using System.Threading.Tasks;

namespace Blazor.Pages
{
    public partial class Tab : OwningComponentBase
    {
        public SfTab SfTab;

        [Parameter]
        public string CssClass { get; set; }

        [Parameter]
        public RenderFragment ChildContent { get; set; }

        [Parameter]
        public TabVariant Variant { get; set; } = TabVariant.Underline;

        [Parameter]
        public EventCallback<SelectEventArgs> TabSelectionChanged { get; set; }

        [Parameter]
        public EventCallback<SelectingEventArgs> HandleSelectingTab { get; set; }

        [Parameter]
        public EventCallback OnCreated { get; set; }

        [Parameter]
        public bool IsPositionedVertically { get; set; }

        [Parameter]
        public bool DisplayWithOverflow { get; set; } = true;

        [Parameter]
        public string Height { get; set; }

        [Parameter]
        public ContentLoad ContentLoad { get; set; } = ContentLoad.Dynamic;

        public int SelectedTabIndex => Convert.ToInt32(SfTab.SelectedItem);

        public List<TabChild> TabChildren { get; private set; } = new List<TabChild>();

        public virtual void HandleTabSelectionChanged(SelectEventArgs eventArgs)
        {
            TabSelectionChanged.InvokeAsync(eventArgs);
        }

        private void HandleOnSelect(SelectingEventArgs arguments)
        {
            HandleSelectingTab.InvokeAsync(arguments);
            if (arguments.IsSwiped)
            {
                arguments.Cancel = true;
            }
        }

        public async Task SwitchTo(int tabIndex)
        {
            if ((int)SfTab.SelectedItem == tabIndex) return;

            SfTab.SelectedItem = SfTab.Items.Count < tabIndex || tabIndex < 0 ? 0 : tabIndex;
            await InvokeAsync(StateHasChanged);
        }

        private string GetVariantClass()
        {
            if (Variant == TabVariant.Box)
            {
                return "box-tab";
            }

            return "underline-tab";
        }
    }
}
