var getDimensions = function () { return ({
    width: window.innerWidth,
    height: window.innerHeight
}); };
var getElementDimensions = function (selector) {
    var element = document.querySelector(selector);
    // browser adds 2 pixels here so we need to subtract them
    return element && {
        width: element.scrollWidth - 2,
        height: element.scrollHeight - 2
    };
};
var getElementPosition = function (selector) {
    var element = document.querySelector(selector);
    var elementPosition = element.getBoundingClientRect();
    return element && {
        top: elementPosition.top,
        left: elementPosition.left
    };
};
var scrollIntoView = function (elementId) {
    var element = document.getElementById(elementId);
    element.scrollIntoView({
        behavior: "smooth",
        block: "center",
        inline: "center"
    });
};
var hasHorizontalScroll = function (selector) {
    if (!selector)
        return false;
    var element = document.querySelector(selector);
    return element.scrollWidth > element.clientWidth;
};
var ElementClassOnResize = /** @class */ (function () {
    function ElementClassOnResize() {
        var _this = this;
        this.init = function (element, targetSelector, className) {
            _this.element = element;
            _this.className = className;
            _this.target = element.querySelector(targetSelector);
            _this.removeListener();
            _this.addListener();
        };
        this.addListener = function () {
            if (_this.hasHorizontalScroll()) {
                _this.element.classList.add(_this.className);
            }
            window.addEventListener("resize", _this.onWindowResize);
        };
        this.removeListener = function () {
            window.removeEventListener("resize", _this.onWindowResize);
        };
        this.onWindowResize = function () {
            if (_this.hasHorizontalScroll()) {
                _this.element.classList.add(_this.className);
            }
            else {
                _this.element.classList.remove(_this.className);
            }
        };
        this.hasHorizontalScroll = function () {
            if (!_this.target)
                return false;
            return _this.target.scrollWidth > _this.target.clientWidth;
        };
    }
    return ElementClassOnResize;
}());
var elementClassOnResize = new ElementClassOnResize();
//# sourceMappingURL=BrowserUtils.js.map