﻿const getDimensions = () => ({
    width: window.innerWidth,
    height: window.innerHeight
});

const getElementDimensions = (selector: string) => {
    const element = document.querySelector(selector);

    // browser adds 2 pixels here so we need to subtract them
    return element && {
        width: element.scrollWidth - 2,
        height: element.scrollHeight - 2
    };
}

const getElementPosition = (selector: string) => {
    const element = document.querySelector(selector);

    const elementPosition = element.getBoundingClientRect();

    return element && {
        top: elementPosition.top,
        left: elementPosition.left
    };
}

const scrollIntoView = (elementId: string) => {
    const element = document.getElementById(elementId);

    element.scrollIntoView({
        behavior: "smooth",
        block: "center",
        inline: "center"
    });
}

const hasHorizontalScroll = (selector: string) => {
    if (!selector) return false;
    const element = document.querySelector(selector);

    return element.scrollWidth > element.clientWidth;
}

class ElementClassOnResize {
    private element: Element;
    private className: string;
    private target: Element;

    init = (element: Element, targetSelector: string, className: string) => {
        this.element = element;
        this.className = className;
        this.target = element.querySelector(targetSelector);

        this.removeListener();
        this.addListener();
    }

    private addListener = () => {
        if (this.hasHorizontalScroll()) {
            this.element.classList.add(this.className);
        }
        window.addEventListener("resize", this.onWindowResize);
    }

    removeListener = () => {
        window.removeEventListener("resize", this.onWindowResize);
    }

    onWindowResize = () => {
        if (this.hasHorizontalScroll()) {
            this.element.classList.add(this.className);
        }
        else {
            this.element.classList.remove(this.className);
        }
    }

    hasHorizontalScroll = () => {
        if (!this.target) return false;

        return this.target.scrollWidth > this.target.clientWidth;
    }
}

const elementClassOnResize = new ElementClassOnResize();
